/**
 * OW2 FraSCAti : Pool composite generator for bench mojo
 * Copyright (C) 2009-2010 INRIA, University of Lille 1
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: frascati@ow2.org
 *
 * Author: Damien Fournier
 */

package org.ow2.frascati.mojo.bench;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;

import org.apache.maven.project.MavenProject;

public class PoolGenerator
{
	public static void generate(SCABenchGenerator generator) throws IOException
	{
		// Maven Project
		MavenProject project = generator.getProject();

		// Composite Size
		int size = generator.getSize();

		// Composite file name
		String filename = generator.getName() + ".composite";

		// Get Base directory
		File baseDir = project.getBasedir();

		// Get Target directory
		File targetDir = new File(baseDir.getAbsolutePath() + File.separator
				+ "src" + File.separator + "main" + File.separator
				+ "resources");

		// Create Target directory if needed
		if (!targetDir.exists())
			targetDir.mkdirs();

		int i = 0;

		File ouputFile = new File(targetDir, filename);

		ouputFile.createNewFile();
		FileOutputStream outputStream = new FileOutputStream(ouputFile);

		String header = "<?xml version=\"1.0\" encoding=\"UTF-8\"?><composite xmlns=\""
				+ generator.getNamespace()
				+ "\" targetNamespace=\"http://bench\" name=\""
				+ generator.getName() + "\">";

		outputStream.write(header.getBytes());

		String component0 = "<component name=\"Component0\"><implementation.java class=\"org.ow2.frascati.examples.bench.ServiceComponent\" /><service name=\"Service\"><interface.java interface=\"org.ow2.frascati.examples.bench.Service\" /></service><reference name=\"ref\" multiplicity=\"0..n\"><interface.java interface=\"org.ow2.frascati.examples.bench.Service\"></interface.java></reference></component>";
		outputStream.write(component0.getBytes());

		for (i = 1; i < size; i++) {
			String component = "<component name=\"Component"
					+ i
					+ "\"><implementation.java class=\"org.ow2.frascati.examples.bench.ServiceComponent\" /><service name=\"Service\"><interface.java interface=\"org.ow2.frascati.examples.bench.Service\" /></service><reference name=\"ref\" multiplicity=\"0..n\"><interface.java interface=\"org.ow2.frascati.examples.bench.Service\"></interface.java></reference></component>";
			outputStream.write(component.getBytes());

			String wire = "<wire source=\"Component0/ref\" target=\"Component"
					+ i + "/Service\"/>";
			outputStream.write(wire.getBytes());

		}

		String end = "<service name=\"s\" promote=\"Component0\"><interface.java interface=\"org.ow2.frascati.examples.bench.Service\"/></service></composite>";
		outputStream.write(end.getBytes());
		outputStream.flush();
		outputStream.close();
	}
}
